@@ -6,20 +6,34 @@ from localstack import config
 from localstack.services import install
 from localstack.utils.aws import aws_stack
 from localstack.constants import DEFAULT_PORT_ELASTICSEARCH_BACKEND, LOCALSTACK_ROOT_FOLDER
-from localstack.utils.common import run, is_root, mkdir, chmod_r
+from localstack.utils.common import is_root, mkdir, chmod_r, rm_rf
 from localstack.services.infra import get_service_protocol, start_proxy_for_service, do_run
 from localstack.services.install import ROOT_PATH
 
-LOGGER = logging.getLogger(__name__)
+LOG = logging.getLogger(__name__)
+
+STATE = {}
 
 
 def delete_all_elasticsearch_data():
     """ This function drops ALL data in the local Elasticsearch data folder. Use with caution! """
     data_dir = os.path.join(LOCALSTACK_ROOT_FOLDER, 'infra', 'elasticsearch', 'data', 'elasticsearch', 'nodes')
-    run('rm -rf "%s"' % data_dir)
+    rm_rf(data_dir)
+
+
+def stop_elasticsearch():
+    thread = STATE.get('_thread_')
+    if not thread:
+        return
+    LOG.info('Terminating Elasticsearch instance, as all clusters have been removed')
+    thread.stop()
+    del STATE['_thread_']
 
 
 def start_elasticsearch(port=None, delete_data=True, asynchronous=False, update_listener=None):
+    if STATE.get('_thread_'):
+        return STATE['_thread_']
+
     port = port or config.PORT_ELASTICSEARCH
     # delete Elasticsearch data that may be cached locally from a previous test run
     delete_all_elasticsearch_data()
@@ -30,6 +44,7 @@ def start_elasticsearch(port=None, delete_data=True, asynchronous=False, update_
     es_tmp_dir = '%s/infra/elasticsearch/tmp' % (ROOT_PATH)
     es_mods_dir = '%s/infra/elasticsearch/modules' % (ROOT_PATH)
     if config.DATA_DIR:
+        delete_data = False
         es_data_dir = '%s/elasticsearch' % config.DATA_DIR
     # Elasticsearch 5.x cannot be bound to 0.0.0.0 in some Docker environments,
     # hence we use the default bind address 127.0.0.0 and put a proxy in front of it
@@ -43,9 +58,9 @@ def start_elasticsearch(port=None, delete_data=True, asynchronous=False, update_
         'ES_JAVA_OPTS': os.environ.get('ES_JAVA_OPTS', '-Xms200m -Xmx600m'),
         'ES_TMPDIR': es_tmp_dir
     }
-    print('Starting local Elasticsearch (%s port %s)...' % (get_service_protocol(), port))
+    LOG.debug('Starting local Elasticsearch (%s port %s)' % (get_service_protocol(), port))
     if delete_data:
-        run('rm -rf %s' % es_data_dir)
+        rm_rf(es_data_dir)
     # fix permissions
     chmod_r('%s/infra/elasticsearch' % ROOT_PATH, 0o777)
     mkdir(es_data_dir)
@@ -58,6 +73,7 @@ def start_elasticsearch(port=None, delete_data=True, asynchronous=False, update_
     if is_root():
         cmd = "su localstack -c '%s'" % cmd
     thread = do_run(cmd, asynchronous, env_vars=env_vars)
+    STATE['_thread_'] = thread
     return thread
 
 
@@ -69,7 +85,7 @@ def check_elasticsearch(expect_shutdown=False, print_error=False):
         out = es.cat.aliases()
     except Exception as e:
         if print_error:
-            LOGGER.error('Elasticsearch health check failed (retrying...): %s %s' % (e, traceback.format_exc()))
+            LOG.error('Elasticsearch health check failed (retrying...): %s %s' % (e, traceback.format_exc()))
     if expect_shutdown:
         assert out is None
     else:
