@@ -111,11 +111,14 @@ def load_plugin_from_path(file_path, scope=None):
         scope = scope or PLUGIN_SCOPE_SERVICES
         if scope == PLUGIN_SCOPE_COMMANDS:
             method_name = 'register_localstack_commands'
+        LOG.debug('Loading plugins - scope "%s", module "%s"' % (scope, module))
         try:
             namespace = {}
             exec('from %s.plugins import %s' % (module, method_name), namespace)
             method_to_execute = namespace[method_name]
         except Exception as e:
+            if "cannot import name 'register_localstack_commands'" not in str(e):
+                print('Unable to load plugins for module "%s": %s' % (module, e))
             if (not re.match(r'.*cannot import name .*%s.*' % method_name, str(e)) and
                     ('No module named' not in str(e))):
                 LOG.debug('Unable to load plugins from module %s: %s' % (module, e))
